Package: systemPipeR
Type: Package
Title: systemPipeR: workflow management and report generation
        environment
Version: 2.10.0
Date: 2024-03-19
Author: Thomas Girke
Maintainer: Thomas Girke <thomas.girke@ucr.edu>
biocViews: Genetics, Infrastructure, DataImport, Sequencing, RNASeq,
        RiboSeq, ChIPSeq, MethylSeq, SNP, GeneExpression, Coverage,
        GeneSetEnrichment, Alignment, QualityControl, ImmunoOncology,
        ReportWriting, WorkflowStep, WorkflowManagement
Description: systemPipeR is a multipurpose data analysis workflow environment that unifies R with command-line tools. It enables scientists to analyze many types of large- or small-scale data on local or distributed computer systems with a high level of reproducibility, scalability and portability. At its core is a command-line interface (CLI) that adopts the Common Workflow Language (CWL). This design allows users to choose for each analysis step the optimal R or command-line software. It supports both end-to-end and partial execution of workflows with built-in restart functionalities. Efficient management of complex analysis tasks is accomplished by a flexible workflow control container class. Handling of large numbers of input samples and experimental designs is facilitated by consistent sample annotation mechanisms. As a multi-purpose workflow toolkit, systemPipeR enables users to run existing workflows, customize them or design entirely new ones while taking advantage of widely adopted data structures within the Bioconductor ecosystem. Another important core functionality is the generation of reproducible scientific analysis and technical reports. For result interpretation, systemPipeR offers a wide range of plotting functionality, while an associated Shiny App offers many useful functionalities for interactive result exploration. The vignettes linked from this page include (1) a general introduction, (2) a description of technical details, and (3) a collection of workflow templates.
Depends: Rsamtools (>= 1.31.2), Biostrings, ShortRead (>= 1.37.1),
        methods
Imports: GenomicRanges, SummarizedExperiment, ggplot2, yaml, stringr,
        magrittr, S4Vectors, crayon, BiocGenerics, htmlwidgets
Suggests: BiocStyle, knitr, rmarkdown, systemPipeRdata,
        GenomicAlignments, grid, dplyr, testthat, rjson, annotate,
        AnnotationDbi, kableExtra, GenomeInfoDb, DT, rtracklayer,
        limma, edgeR, DESeq2, IRanges, batchtools, GenomicFeatures,
        txdbmaker, VariantAnnotation (>= 1.25.11)
VignetteBuilder: knitr
SystemRequirements: systemPipeR can be used to run external
        command-line software (e.g. short read aligners), but the
        corresponding tool needs to be installed on a system.
License: Artistic-2.0
URL: https://systempipe.org/, https://github.com/tgirke/systemPipeR
git_url: https://git.bioconductor.org/packages/systemPipeR
git_branch: RELEASE_3_19
git_last_commit: 4521e19
git_last_commit_date: 2024-04-30
Repository: Bioconductor 3.19
Date/Publication: 2024-05-01
NeedsCompilation: no
Packaged: 2024-05-01 23:43:55 UTC; biocbuild
Built: R 4.4.0; ; 2024-05-24 15:09:30 UTC; unix
